@@ -5,20 +5,20 @@ import time
 from performance import config
 from performance.config import WORK_DIR
 
-VERSION = [0, 0, 23]
+VERSION = [0, 1, 1]
 
 
-DEBUG = config.DEBUG
+DEBUG = config.DEBUG()
 
 # dump时间间隔(s)
-DUMP_INTERVAL = config.dump_interval
+DUMP_INTERVAL = config.dump_interval()
 
 # 表单名称
 SHEET_NAME = "memory"
 
 TODAY = time.strftime("%Y-%m-%d")
 
-TIME = time.strftime("%H-%M-%S")
+TIME = time.strftime("%H:%M:%S")
 
 COLORS = ['none', 'red', 'yellow', 'gray', 'blue', 'black', 'pink', '#ff34b3', '#fff8dc']
 
