@@ -1,24 +1,24 @@
+import os
 import smtplib
 from email.mime.application import MIMEApplication
 from email.mime.image import MIMEImage
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
-from performance import TODAY, DEBUG, config
+from performance import TODAY, DEBUG, config, lint, checkstyle
 
 
 def send_mail(report):
     assert isinstance(report, Report)
     # 设置smtplib所需的参数
     # 下面的发件人，收件人是用于邮件传输的。
-    smtpserver = config.smtp_server
-    username = config.user_name
-    password = config.password
-    sender = config.sender
+    smtpserver = config.smtp_server()
+    username = config.user_name()
+    password = config.password()
+    sender = config.sender()
     # 收件人为多个收件人
-    receiver = config.mail_to
-
-    cc = config.cc
+    receiver = config.mail_to()
+    cc = config.cc()
 
     subject = '%s内存检查报告(%s)' % (report.pkg, TODAY)
     # 通过Header对象编码的文本，包含utf-8编码信息和Base64编码信息。以下中文名测试ok
@@ -33,8 +33,11 @@ def send_mail(report):
     # msg['To'] = 'XXX@126.com'
     # 收件人为多个收件人,通过join将列表转换为以;为间隔的字符串
     msg['To'] = ";".join(receiver)
-    msg['Cc'] = ";".join(cc)
     # msg['Date']='2012-3-16'
+    msg['Cc'] = ";".join(cc)
+
+    lints = lint.get_errors_warnings(report.lint_file)
+    checkstyles = checkstyle.get_errors_warnings(report.checkstyle_file)
 
     # 构造文字内容
     text = """
@@ -54,6 +57,9 @@ def send_mail(report):
             <p>
             <div><b>ANR 数量:</b> %d</div>
             <div><b>App Crash数量:</b> %d</div>
+            
+            <div><b>%s</div>
+            <div><b>%s</div>
 
             <p></p>
             <div><b>内存最大值:</b> %s(KB)</div>
@@ -68,7 +74,7 @@ def send_mail(report):
         </body>
         </html>
     """ % (TODAY, report.success, report.duration, report.pkg, report.device,
-           len(report.anrs), len(report.crashes), report.max, report.avg)
+           len(report.anrs), len(report.crashes), lints, checkstyles, report.max, report.avg)
 
     plt_simple = open(report.plt_simple, 'rb').read()
     plt_simple_image = MIMEImage(plt_simple)
@@ -87,20 +93,32 @@ def send_mail(report):
     for anr in report.anrs:
         anr_file = MIMEText(open(anr, 'rb').read(), 'base64', 'utf-8')
         anr_file["Content-Type"] = 'application/octet-stream'
-        anr_file["Content-Disposition"] = 'attachment; filename=%s' % anr
+        anr_file["Content-Disposition"] = 'attachment; filename=%s' % os.path.split(anr)[1]
         msg.attach(anr_file)
 
     for crash in report.crashes:
         crash_file = MIMEText(open(crash, 'rb').read(), 'base64', 'utf-8')
         crash_file["Content-Type"] = 'application/octet-stream'
-        crash_file["Content-Disposition"] = 'attachment; filename=%s' % crash
+        crash_file["Content-Disposition"] = 'attachment; filename=%s' % os.path.split(crash)[1]
         msg.attach(crash_file)
 
     xlsx_file = MIMEApplication(open(report.xlsx, 'rb').read())
     xlsx_file["Content-Type"] = 'application/octet-stream'
-    xlsx_file["Content-Disposition"] = 'attachment; filename=%s' % report.xlsx
+    xlsx_file["Content-Disposition"] = 'attachment; filename=%s' % os.path.split(report.xlsx)[1]
     msg.attach(xlsx_file)
 
+    if os.path.exists(report.lint_file):
+        lint_file = MIMEText(open(report.lint_file, "rb").read(), 'base64', 'utf-8')
+        lint_file["Content-Type"] = 'application/octet-stream'
+        lint_file["Content-Disposition"] = 'attachment; filename=%s' % os.path.split(report.lint_file)[1]
+        msg.attach(lint_file)
+
+    if os.path.exists(report.checkstyle_file):
+        checkstyle_file = MIMEText(open(report.checkstyle_file, "rb").read(), 'base64', 'utf-8')
+        checkstyle_file["Content-Type"] = 'application/octet-stream'
+        checkstyle_file["Content-Disposition"] = 'attachment; filename=%s' % os.path.split(report.lint_file)[1]
+        msg.attach(checkstyle_file)
+
     # 发送邮件
     smtp = smtplib.SMTP()
     smtp.connect(smtpserver)
@@ -126,3 +144,5 @@ class Report:
         self.anrs = []
         self.plt_history = None
         self.success = True
+        self.lint_file = ''
+        self.checkstyle_file = ''
